@@ -13,7 +13,7 @@ use English qw/ -no_match_vars /;
 use App::Git::Workflow;
 use App::Git::Workflow::Command qw/get_options/;
 
-our $VERSION = version->new(1.1.12);
+our $VERSION = version->new(1.1.13);
 our $workflow = App::Git::Workflow->new;
 my ($name)   = $PROGRAM_NAME =~ m{^.*/(.*?)$}mxs;
 our %option;
@@ -108,7 +108,12 @@ sub do_delete {
 
         if ( !$option{test} ) {
             if ($remote) {
-                $workflow->git->push($remote, ":refs/heads/$name");
+                eval {
+                    $workflow->git->push($remote, ":refs/heads/$name");
+                    1;
+                } or do {
+                    return 0;
+                }
             }
             else {
                 $workflow->git->branch('-D', "$name");
@@ -155,7 +160,7 @@ git-branch-clean - Clean old branches out of the repository
 
 =head1 VERSION
 
-This documentation refers to git-branch-clean version 1.1.12
+This documentation refers to git-branch-clean version 1.1.13
 
 =head1 SYNOPSIS
 
